import ctypes
import os

# Determinar la extensión de la biblioteca compartida según el sistema operativo
if os.name == "nt":
    lib_name = "cpp_functions.dll"
else:
    lib_name = "cpp_functions.so"

# Ruta a la biblioteca compartida compilada
lib_path = os.path.join(os.path.dirname(__file__), lib_name)
cpp_lib = ctypes.CDLL(lib_path)

def hello_from_cpp():
    cpp_lib.hello_from_cpp()

def hello_from_python():
    print("Hello from Python!")



from setuptools import setup, Extension
from Cython.Build import cythonize

# ... (otros imports si necesarios)

# Extensión para compilar el código C++
extension = Extension(
    "packagePepe.module_cpp",
    sources=["packagePepe/cpp_functions.cpp"],
    # ... (otras opciones de compilación, si es necesario)
)

setup(
    name="packagePepe",
    version="0.1.5",
    description="Mi primer paquete con C++ y Python",
    author="Tu Nombre",
    author_email="tu_email@example.com",
    packages=["packagePepe"],
    ext_modules=cythonize(extension),
)
